@@ -1,6 +1,8 @@
 from django.conf import settings
 from django.views.generic import ListView
 
+from django_master.views import MasterContextMixin
+
 
 
 class Route(object):
@@ -36,9 +38,10 @@ class Route(object):
         return sorted([Route(url, base=self.url) for url in urls], key=lambda x: x.url)
 
 
-class RoutesListView(ListView):
+class RoutesListView(ListView, MasterContextMixin):
     template_name = 'django_master/routes.html'
-    context_object_name = "route_list"
+    context_object_name = 'route_list'
+    menu_item = 'routes'
 
 
     def get_queryset(self):
