@@ -3,11 +3,13 @@ from collections import OrderedDict
 from django.conf import settings
 from django.views.generic import ListView
 
+from django_master.views import MasterContextMixin
 
-class SettingsListView(ListView):
+
+class SettingsListView(ListView, MasterContextMixin):
     template_name = 'django_master/settings.html'
-    context_object_name = "settings"
-
+    context_object_name = 'settings'
+    menu_item = 'settings'
 
     def get_queryset(self):
         ret = OrderedDict()
